# **Transito**:  Userguide

[Transito](http://git.sr.ht/~mil/transito) is FOSS
data-provider-agnostic public transportation app that let's you route
between locations using openly available public GTFS feeds. For
an overview of Transito's functionality see [Transito's project
page](http://git.sr.ht/~mil/transito). This document is a guide on how
to get Transito setup on your local device.

- *1:* [Install](#stronginstallstrong)
- *2:* [Primer Documentation](#strongprimer-documentationstrong)
- *3:* [Usage](#strongusagestrong)

## **Install**

- **Android**
  - Currently an Android app is built via continuous integration.
  - Transito on Android requires a minimum of Android 11.
  - Download & install the Android APK from [https://ci.lrdu.org/android/](https://ci.lrdu.org/android/)
    - Builds tagged as `master`: Latest builds / features development, may be less stable
    - Builds tagged as `0.x.0`: Tagged builds for specific releases, see [Release Notes](https://git.sr.ht/~mil/transito/refs) for details on changes
- **Linux / Desktop**
  - Using Transito on desktop is currently possible however covered in a [separate guide for advanced usage / builds](https://git.sr.ht/~mil/transito/tree/master/item/doc/doc_transito_build_from_source.md)

## **Primer Documentation**

- Before using Transito, please read the following documentation:
  - [Transito: Project Overview & Featureset](https://git.sr.ht/~mil/transito)
  - [Mobroute: What is MDBID and the Mobility Database Doc](https://git.sr.ht/~mil/mobroute/tree/master/doc/doc_mdbid.md)
  - [Mobroute: Algorithm Tunable Parameters](https://git.sr.ht/~mil/mobroute/tree/master/doc/doc_tunables.md)

## **Usage**

This section will guide you through a basic routing request using an
example of using the Agglobus provider in Bourges, France (MDBID:
1898). You may wish to change your GTFS datafeed and search terms,
however if you're unclear about how to use the app, this is a good guide
to follow along with:


<table>
  <tr>
    <td><strong>Screenshot</strong></td>
    <td><strong>Description</strong></td>
  </tr>
  <tr>
    <td>
      <a href="doc_transito_screenshots.md"><img src='/~mil/transito/blob/app-doc-rework/doc/transito_screenshot_config.png' /></a>
    </td>
    <td>
      <strong>Config:</strong>
      <ul>
        <li>After launching the app, by default you will be on the <strong>Route</strong> page.</li>
        <li>Switch tabs to the <strong>Config</strong> page.</li>
        <li>On the <strong>Config</strong> page, you can change the <strong>MDBID(s)</strong> which are used for routing requests.</li>
        <li>For our example, enter the <strong>1898</strong> as the MDBID which correlates to Agglobus provider in Bourges, France.</li>
        <li>Different providers of GTFS datafeeds each have their own specific MDBID, you can learn more about this at the <a href="https://git.sr.ht/~mil/mobroute/tree/master/doc/doc_mdbid.md">MDBID guide</a>.</li>
        <li>You can interactively search for an appropriate GTFS provider datafeed at the <a href="https://mdb.lrdu.org/">Mobility Database UI</a>.</li>
        <li>Once you have your MDBID set; switch to the <strong>Search</strong> page.</li>
      </ul>
    </td>
  </tr>
  <tr>
    <td>
      <a href="doc_transito_screenshots.md"><img src='/~mil/transito/blob/app-doc-rework/doc/transito_screenshot_search.png' /></a>
    </td>
    <td>
      <strong>Search:</strong>
      <ul>
        <li>On the <strong>Search</strong> page, you can search for either POIs or direct addresses by using <a href="https://nominatim.org/">Nominatim</a>.</li>
        <li>For our example, we will route starting from "Camping de Bourges" so simply enter that into the search field and press the "Search" button.</li>
        <li>In the select list below you will see results; you can pick among multiple results if there is more then 1 match.</li>
        <li>Once you've determined the correct location, press "Set as From".</li>
        <li>You will be taken back to the <strong>Route</strong> page and see that the From location is set.</li>
        <li>Now, either click the "To:" text or switch back to the <strong>Search</strong> page again by clicking its tab.</li>
        <li>For our example, we will route to "Velodrome" so go through the steps as previously, but this time around hit "Set as To".</li>
      </ul>
    </td>
  </tr>
  <tr>
    <td>
      <a href="doc_transito_screenshots.md"><img src='/~mil/transito/blob/app-doc-rework/doc/transito_screenshot_routesteps.png' /></a>
    </td>
    <td>
      <strong>Route:</strong>
      <ul>
        <li>Now from and to locations are set, and you're on the <strong>Route</strong> page.</li>
        <li>From here, to submit a routing request, simply press the "Route" button.</li>
        <li>The first time routing with a given GTFS datafeed (MDBID) may be a bit slow (on the order of minutes).</li>
        <li>On first request, GTFS data is downloaded in the background from the source agency, imported into a format for simple routing.</li>
        <li>Subsequent requests using the same GTFS datafeed (MDBID) will be substantially faster; as GTFS data is cached.</li>
        <li>
          Once the route has been calculated:
          <ul>
            <li>Clicking "Overview" shows the steps for the route.</li>
            <li>Clicking the "Map" button opens a URL to show the route on a map.</li>
            <li>Clicking "Dbg" shows diagnostics information about the route & performance details.</li>
            <li>
              Clicking "Req" shows the request serialized to JSON
              <ul>
                <li>Also clicking this tab automatically copies the JSON request to the clipboard.</li>
                <li>Request can be used via mobroute's CLI as: `mobroute route -p 'JSON'`.</li>
                <li>Please include this request in any bug reports regarding generated routes for reproducibility.</li>
              </ul>
            </li>
          </ul>
        </li>
      </ul>
    </td>
  </tr>
</table>

---

> [All Transito Docs](http://git.sr.ht/~mil/transito)
